@@ -14,6 +14,7 @@ from interactions import (
     InteractionException,
     Option,
     OptionType,
+    Snowflake,
 )
 
 from ._logging import get_logger
@@ -105,9 +106,70 @@ class Group:
         )
 
 
+class GroupSetup:
+    """
+    A class that allows a shortcut to creating a group subcommand in the original `SubcommandSetup`.
+
+    ```py
+    base_var: SubcommandSetup = client.subcommand_base("base_name", ...)
+    group_var: GroupSetup = base_var.group("group_name")
+
+    group_var.subcommand(...)
+    async def group_subcommand(ctx, ...):
+        ...
+    ```
+
+    Parameters:
+
+    * `group: str`: The name of the subcommand group.
+    * `subcommand_setup: SubcommandSetup`: The `SubcommandSetup` to add the group subcommand to.
+    """
+
+    def __init__(self, group: str, subcommand_setup: "SubcommandSetup"):
+        log.debug(f"GroupSetup.__init__: {group=}, {subcommand_setup=}")
+        self.group: str = group
+        self.subcommand_setup: "SubcommandSetup" = subcommand_setup
+
+    def subcommand(
+        self,
+        name: Optional[str] = MISSING,
+        description: Optional[str] = MISSING,
+        options: Optional[List[Option]] = MISSING,
+    ) -> Callable[..., Any]:
+        """
+        Creates a subcommand with the specified group and parameters.
+
+        ```py
+        base_var: SubcommandSetup = client.subcommand_base("base_name", ...)
+        group_var: GroupSetup = base_var.group("group_name")
+
+        group_var.subcommand(...)
+        async def group_subcommand(ctx, ...):
+            ...
+        ```
+
+        Parameters:
+
+        * `?name: str`: The name of the subcommand.
+        * `?description: str`: The description of the subcommand.
+        * `?options: List[Option]`: The options of the subcommand.
+        """
+
+        def decorator(coro):
+            self.subcommand_setup.subcommand(
+                group=self.group,
+                name=name,
+                description=description,
+                options=options,
+            )(coro)
+            return coro
+
+        return decorator
+
+
 class SubcommandSetup:
     """
-    A class you get when using `base_var = client.base("base_name", ...)`
+    A class you get when using `base_var = client.subcommand_base("base_name", ...)`
 
     Use this class to create subcommands by using the `@base_name.subcommand(...)` decorator.
 
@@ -143,6 +205,28 @@ class SubcommandSetup:
 
         self.groups: Dict[str, Group] = {}
         self.subcommands: Dict[str, Subcommand] = {}
+        self.commands: List[ApplicationCommand] = MISSING
+
+    def group(self, group: str) -> GroupSetup:
+        """
+        Function to get a `GroupSetup` object, a shortcut to creating group subcommands.
+
+        This is also in `ExternalSubcommandSetup`.
+
+        ```py
+        base_var: SubcommandSetup = client.subcommand_base("base_name", ...)
+        group_var: GroupSetup = base_var.group("group_name")
+        ```
+
+        Parameters:
+
+        * `group: str`: The name of the group.
+
+        Returns:
+
+        `GroupSetup`
+        """
+        return GroupSetup(group=group, subcommand_setup=self)
 
     def subcommand(
         self,
@@ -184,7 +268,6 @@ class SubcommandSetup:
                 raise ValueError("Description must be less than 100 characters.")
 
             params = signature(coro).parameters
-            print(hasattr(coro, "__decor_options"), "lol")
             _options = (
                 getattr(coro, "__decor_options")
                 if hasattr(coro, "__decor_options")
@@ -204,7 +287,7 @@ class SubcommandSetup:
             elif group not in self.groups:
                 self.groups[group] = Group(
                     group,
-                    description,
+                    _description,
                     subcommand=Subcommand(_name, _description, coro, _options),
                 )
             else:
@@ -233,7 +316,7 @@ class SubcommandSetup:
             else []
         )
         options = (group_options + subcommand_options) or None
-        commands: List[ApplicationCommand] = command(
+        self.commands: List[ApplicationCommand] = command(
             type=ApplicationCommandType.CHAT_INPUT,
             name=self.base,
             description=self.description,
@@ -246,16 +329,14 @@ class SubcommandSetup:
             if self.client._loop.is_running():
                 [
                     self.client._loop.create_task(self.client._synchronize(command))
-                    for command in commands
+                    for command in self.commands
                 ]
             else:
                 [
                     self.client._loop.run_until_complete(self.client._synchronize(command))
-                    for command in commands
+                    for command in self.commands
                 ]
 
-        print(f"{self.scope=} {self.base=}")
-
         if self.scope is not MISSING:
             if isinstance(self.scope, list):
                 [self.client._scopes.add(_ if isinstance(_, int) else _.id) for _ in self.scope]
@@ -277,6 +358,78 @@ class SubcommandSetup:
 
         return self.client.event(inner, name=f"command_{self.base}")
 
+    def autocomplete(self, option: str) -> Callable[..., Any]:
+        """
+        Decorator for building autocomplete for options in the current base.
+
+        **IMPORTANT**: You must `base_var.finish()` before using this decorator.
+
+        Example:
+
+        ```py
+        base = client.subcommand_base("base_name", ...)
+
+        @base.subcommand()
+        @option("auto", autocomplete=True)
+        async def subcommand(ctx, auto: str):
+            ...
+
+        ...
+        base.finish()
+
+        @base.autocomplete("auto")
+        async def auto_complete(ctx, user_input: str = ""):
+            await ctx.populate([
+                interactions.Choice(...),
+                interactions.Choice(...),
+                ...
+            ])
+        ```
+
+        Parameters:
+
+        * `option: str`: The option to build autocomplete for.
+        """
+
+        def decorator(coro: Coroutine) -> Callable[..., Any]:
+            if self.commands is MISSING:
+                raise RuntimeError(
+                    "You must `base_var.finish()` the setup of the subcommands before providing autocomplete."
+                )
+            command: str = self.base
+            _command_obj: ApplicationCommand = self.client._http.cache.interactions.get(command)
+            if not _command_obj or not _command_obj.id:
+                if getattr(_command_obj, "guild_id", None) or self._automate_sync:
+                    _application_commands: List[
+                        ApplicationCommand
+                    ] = self.client._loop.run_until_complete(
+                        self.client._http.get_application_commands(
+                            application_id=self.me.id,
+                            guild_id=None
+                            if not hasattr(_command_obj, "guild_id")
+                            else _command_obj.guild_id,
+                        )
+                    )
+                    _command_obj: ApplicationCommand = self.client._find_command(
+                        _application_commands, command
+                    )
+                else:
+                    for _scope in self._scopes:
+                        _application_commands: List[
+                            ApplicationCommand
+                        ] = self.client._loop.run_until_complete(
+                            self.client._http.get_application_commands(
+                                application_id=self.me.id, guild_id=_scope
+                            )
+                        )
+                        _command_obj: ApplicationCommand = self.client._find_command(
+                            _application_commands, command
+                        )
+            _command: Union[Snowflake, int] = int(_command_obj.id)
+            return self.client.event(coro, name=f"autocomplete_{_command}_{option}")
+
+        return decorator
+
 
 class ExternalSubcommandSetup(SubcommandSetup):
     """
@@ -454,7 +607,7 @@ def subcommand_base(
     To use this function without loading the extension, pass in the client as the first argument.
 
     ```py
-    base_name = client.base(
+    base_name = client.subcommand_base(
         "base_name",
         description="Description of the base",
         scope=123456789,
